%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%                   MeetingAbstracts.cls                   %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% This is a class (.cls) file for LaTeX2e.
%%
%% Author:      Lluís Alsedà
%%              Departament de Matemàtiques
%%              Universitat Autònoma de Barcelona
%%              08193-Cerdanyola del Vallès
%%              Barcelona, SPAIN
%%
%%              alseda@mat.uab.cat
%%
%% Feel free to copy, modify, and distribute.
%% I am interested in all changes you make.
%% Send relevant changes to alseda@mat.uab.cat
%%
%% My purpose in writing this .cls is create a style for
%% meetings abstracts that allows to extract information from
%% LaTeX file and, at the same time, it allows to process the
%% abstracts as a standalone document and as abstracts book
%% (with the help of the subordinated package AbstractsBook)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ToDo: Make \collaborators incompatible with mutiple authors
%% Implementar els controls que hi ha a MakeAbstractsbook
%% Això s'hauria de fer a nivell de latex
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\NeedsTeXFormat{LaTeX2e}
\def\classname{MeetingAbstracts}
\ProvidesClass{\classname} [2012/05/27 v1.1 for meeting standalone abstracts]
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ProcessOptions
\LoadClass[14pt, a4paper]{extarticle}

%%%%%%%%%%%%%%%%%%%%
% Default Packages %
%%%%%%%%%%%%%%%%%%%%
%\RequirePackage{amsmath,amsfonts,amssymb,amsthm,enumerate}
\RequirePackage{amsmath,amssymb,amsthm,enumerate}
%\RequirePackage{palatino}
\RequirePackage[mathscr]{eucal}
\RequirePackage{url}
\RequirePackage{graphicx}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Margins, textwidths, indentations etc %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\setlength\textwidth {175mm}
\setlength\textheight{240mm}
\setlength{\topmargin}{-15mm}
\setlength{\headheight}{0pt}
\setlength{\parskip}{5pt plus 2pt minus 1 pt}
%
\setlength\oddsidemargin  {\paperwidth}
\addtolength\oddsidemargin{-\textwidth}
\divide\oddsidemargin by 2
\addtolength\oddsidemargin{-1in}
\addtolength\oddsidemargin{-\hoffset}
\setlength\evensidemargin {\oddsidemargin}

\addtolength\oddsidemargin{+5mm}
\addtolength\evensidemargin{-5mm}

%%%%%%%%%%%%%%%%%%%%
%  Class  Commands %
%%%%%%%%%%%%%%%%%%%%
\def\ThisClassError#1{\ClassError{\classname}{#1}{}}

%%%%%%%%%%%%%%%%%%%%%
% Basic environment %
%%%%%%%%%%%%%%%%%%%%%
\renewenvironment{abstract}{\document%
\ifnum\c@author@number>1\ifx\@speaker@name\relax\ThisClassError{There are more than one authors and no \noexpand\speaker has been given}\fi\fi%
\maketitle\thispagestyle{empty}}{\enddocument}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Title, authors, address et al. %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\def\speaker#1#2{\def\@speaker@name{#1 #2}\@author@base@command[\underline]{#1}{#2}}
\def\author#1#2{\@author@base@command[\relax]{#1}{#2}}
\def\@collaborators{}
\def\collaborators#1{\ifx\@collaborators\empty\gdef\@collaborators{\par\par\smallskip\par\par{(in collaboration with #1)}}\fi}

\newcounter{author@number}
\let\@speaker@name\relax
\def\@author@base@command[#1]#2#3{
  \def\@dummy{#2}\ifx\@dummy\empty\ThisClassError{Missing given name in \noexpand\author command}\fi
  \def\@dummy{#3}\ifx\@dummy\empty\ThisClassError{Missing family name in \noexpand\author command}\fi
  \ifcase\c@author@number\def\@author{#1{#2 #3}}
  \or\xdef\@author{\@author$^\arabic{author@number}$}
  \fi
  \addtocounter{author@number}{1}
  \expandafter\gdef\csname @address\romannumeral\the\c@author@number\endcsname{\ThisClassError{No \noexpand\address given}}
  \expandafter\gdef\csname @email\romannumeral\the\c@author@number\endcsname{}
  \expandafter\gdef\csname @urladdr\romannumeral\the\c@author@number\endcsname{}
  \ifnum\c@author@number>1
    \g@addto@macro\@author{, \mbox{#1{#2 #3}}}\xdef\@author{\@author$^\arabic{author@number}$}
  \fi
}

\def\address#1{%
   \def\@dummy{#1}\ifx\@dummy\empty\ThisClassError{No \noexpand\address given}\fi%
   \expandafter\gdef\csname @address\romannumeral\the\c@author@number\endcsname{#1}%
}
\def\email#1{\expandafter\gdef\csname @email\romannumeral\the\c@author@number\endcsname{E-mail: {\upshape \url{#1}}}}
\def\urladdr#1{\expandafter\gdef\csname @urladdr\romannumeral\the\c@author@number\endcsname{URL: {\upshape \url{http://#1}}}}

\def\@write@url@line#1{\vskip -1ex\par\par{\small#1}\par\par}
\def\@maketitle{\begin{center} \let \footnote \thanks
    {\Large \textbf{\@title}\par}
    \vskip 0.5em
    {\large \textsc{\@author}\ifnum\c@author@number=1\@collaborators\fi}
    \vspace*{-5mm}
  \end{center}\par\par
  \begingroup \itshape
  \ifnum\c@author@number>1\medskip\par\par
    \count@\@ne
    \loop $^\the\count@$ \csname @address\romannumeral\the\count@\endcsname
       \par\par
       \expandafter\ifx\csname @email\romannumeral\the\count@\endcsname\empty
           \expandafter\ifx\csname @urladdr\romannumeral\the\count@\endcsname\empty\else
               \@write@url@line{\csname @urladdr\romannumeral\the\count@\endcsname}
           \fi
       \else
           \setbox\z@\hbox{{\small\csname @email\romannumeral\the\count@\endcsname\quad\csname @urladdr\romannumeral\the\count@\endcsname}}
           \ifdim\wd\z@>\textwidth\def\@url@sep{\newline}\else\def\@url@sep{\quad}\fi
           \@write@url@line{\csname @email\romannumeral\the\count@\endcsname\@url@sep\csname @urladdr\romannumeral\the\count@\endcsname}
       \fi
    \ifnum\count@<\c@author@number\advance\count@ by 1\repeat
  \else
    \setbox\z@\hbox{\itshape\@emaili}\setlength\@tempdima{\wd\z@}%
    \setbox\z@\hbox{\itshape\@urladdri}\ifdim\wd\z@>\@tempdima\setlength\@tempdima{\wd\z@}\fi
%    \begin{center} % eliminar això per no centrar els autors
      \@addressi\par\par\parbox{\@tempdima}{\raggedright \ifx\@emaili\empty\else \@emaili\\ \fi \@urladdri}
%    \end{center} % eliminar això per no centrar els autors
  \fi
  \endgroup
  \par\par\vskip 0.25em
}

%
% Bibliography
% We want to supress the optional parameter of \bibitem
\def\@lbibitem[#1]#2{\@bibitem{#2}}
\def\@newl@bel#1#2#3{%
   \def\@dummy{#2}\ifx\@dummy\empty\ThisClassError{\noexpand\bibitem cannot be empty}\fi%
  {\@ifundefined{#1@#2}%
    \relax
    {\gdef \@multiplelabels {%
       \ThisClassError{There were multiply-defined labels}}%
     \ThisClassError{Label `#2' multiply defined}}%
  \global\@namedef{#1@#2}{#3}}}
%%%%%%%%%%%%%%%%%%%%%%%
% Initial declarations %
%%%%%%%%%%%%%%%%%%%%%%%%
\sloppy
\flushbottom
\frenchspacing
\endinput
